#ifndef  REFRINGE_H__
#define  REFRINGE_H__ 

#define ALREADY_USED -1
#define END_OF_LIST  -2

typedef struct
    {
    int files_index;
    char baseline[3];
    char subgroup;
    } bsgstruct;


#endif

